@@ -24,7 +24,7 @@
 #include <string.h>
 #include <bonobo-activation/bonobo-activation.h>
 #include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-i18n.h>
+#include "gnome-db-i18n.h"
 #include <gconf/gconf.h>
 #include <libgda/gda-log.h>
 #include <libgnomedb/gnome-db-config.h>
@@ -90,27 +90,21 @@ activation_property_to_parameter (Bonobo_ActivationProperty *prop)
 
         switch (prop->v._d) {
         case Bonobo_ACTIVATION_P_STRING :
-                param = gda_parameter_new ((const gchar *) prop->name, GDA_VALUE_TYPE_STRING);
-                gda_value_set_string ((GdaValue *) gda_parameter_get_value (param),
-                                      prop->v._u.value_string);
+                param = gda_parameter_new_string ((const gchar *) prop->name, prop->v._u.value_string);
                 break;
         case Bonobo_ACTIVATION_P_NUMBER :
-                param = gda_parameter_new ((const gchar *) prop->name, GDA_VALUE_TYPE_DOUBLE);
-                gda_value_set_double ((GdaValue *) gda_parameter_get_value (param),
-                                      prop->v._u.value_number);
+                param = gda_parameter_new_double ((const gchar *) prop->name, prop->v._u.value_number);
                 break;
         case Bonobo_ACTIVATION_P_BOOLEAN :
-                param = gda_parameter_new ((const gchar *) prop->name, GDA_VALUE_TYPE_BOOLEAN);
-                gda_value_set_boolean ((GdaValue *) gda_parameter_get_value (param),
-                                       prop->v._u.value_boolean);
+                param = gda_parameter_new_boolean ((const gchar *) prop->name, prop->v._u.value_boolean);
                 break;
         case Bonobo_ACTIVATION_P_STRINGV :
-                param = gda_parameter_new ((const gchar *) prop->name, GDA_VALUE_TYPE_STRING);
                 str = activation_property_to_string (prop);
                 if (str) {
-                        gda_value_set_string ((GdaValue *) gda_parameter_get_value (param), str);
+			param = gda_parameter_new_string ((const gchar *) prop->name, str);
                         g_free (str);
-                }
+                } else
+			param = NULL;
                 break;
         default :
                 param = NULL;
@@ -441,7 +435,7 @@ void
 gnome_db_config_remove_section (const gchar * path)
 {
 	GSList *slist, *iter;
-	gchar *key;
+	const gchar *key;
 	g_return_if_fail (path != NULL);
 	
 	slist = gconf_client_all_entries (get_conf_client (), path, NULL);
@@ -681,7 +675,7 @@ gnome_db_config_find_data_source (const gchar *name)
 	for (l = dsnlist; l != NULL; l = l->next) {
 		GdaDataSourceInfo *tmp_info = (GdaDataSourceInfo *) l->data;
 
-		if (tmp_info && !g_strcasecmp (tmp_info->name, name)) {
+		if (tmp_info && !strcmp (tmp_info->name, name)) {
 			info = gnome_db_config_copy_data_source_info (tmp_info);
 			break;
 		}
