@@ -190,12 +190,16 @@ GtkWidget*
 gnome_db_error_dialog_new (gchar *title)
 {
 	GnomeDbErrorDialog *dialog;
+	GdkPixbuf *icon;
 
 	dialog = g_object_new (GNOME_DB_TYPE_ERROR_DIALOG, NULL);
 	if (title)
 		gnome_db_error_dialog_set_title (dialog, title);
-	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+        icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+        if (icon) {
+                gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+                g_object_unref (icon);                                         
+        }                                                                      
 	if (title)
 		gnome_db_error_dialog_set_title (dialog, title);
 
