@@ -99,6 +99,7 @@ menu_describe_cb (GtkWidget *widget, gpointer user_data)
 {
 	GtkWidget *dialog;
 	GtkWidget *description;
+	GdkPixbuf *icon;
 	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
@@ -109,9 +110,11 @@ menu_describe_cb (GtkWidget *widget, gpointer user_data)
 		GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (grid))), 0,
 		GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 		NULL);
-	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
-
+        icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+        if (icon) {
+                gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+                g_object_unref (icon);
+        }                                                                       
 	description = gnome_db_table_editor_new ();
 	gtk_widget_show (description);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), description, TRUE, TRUE, 0);
@@ -203,6 +206,7 @@ menu_save_as_cb (GtkWidget *widget, gpointer user_data)
 	GtkWidget *to_tab;
 	GtkWidget *to_comma;
 	GtkWidget *to_xml;
+	GdkPixbuf *icon;
 	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
@@ -215,8 +219,11 @@ menu_save_as_cb (GtkWidget *widget, gpointer user_data)
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK, GTK_RESPONSE_OK,
 		NULL);
-	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+	        icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+        if (icon) {
+                gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+                g_object_unref (icon);
+        }
 	table = gnome_db_new_table_widget (6, 2, FALSE);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, TRUE, TRUE, 0);
 
@@ -280,6 +287,7 @@ menu_view_detail_cb (GtkWidget *widget, gpointer user_data)
 {
 	GtkWidget *dialog;
 	GtkWidget *form;
+	GdkPixbuf *icon;
 	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
 
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
@@ -290,8 +298,12 @@ menu_view_detail_cb (GtkWidget *widget, gpointer user_data)
 		GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (grid))), 0,
 		GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 		NULL);
-	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+        icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+        if (icon) { 
+                gtk_window_set_icon (GTK_WINDOW (dialog), icon); 
+                g_object_unref (icon);
+        }                                                                       
+
 
 	form = gnome_db_form_new ();
 	gtk_widget_show (form);
